@@ -20,6 +20,7 @@ limitations under the License.
 #include <unordered_map>
 
 // logging
+#include "absl/memory/memory.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/string_view.h"
 #include <pybind11/pybind11.h>
@@ -721,13 +722,13 @@ void AssertSameStructure(PyObject* o1, PyObject* o2, bool check_types) {
 
 ValueIteratorPtr GetValueIterator(PyObject* nested) {
   if (PyDict_Check(nested)) {
-    return std::make_unique<DictValueIterator>(nested);
+    return absl::make_unique<DictValueIterator>(nested);
   } else if (IsMappingHelper(nested)) {
-    return std::make_unique<MappingValueIterator>(nested);
+    return absl::make_unique<MappingValueIterator>(nested);
   } else if (IsAttrsHelper(nested)) {
-    return std::make_unique<AttrsValueIterator>(nested);
+    return absl::make_unique<AttrsValueIterator>(nested);
   } else {
-    return std::make_unique<SequenceValueIterator>(nested);
+    return absl::make_unique<SequenceValueIterator>(nested);
   }
 }
 
